@@ -189,7 +189,7 @@ class CellRendererCuemiacCategory (gtk.CellRendererText):
             # Not a treeview
             return False
         
-        if event.type != gtk.gdk.BUTTON_PRESS:
+        if event == None or event.type != gtk.gdk.BUTTON_PRESS:
             # Event type not GDK_BUTTON_PRESS
             return True
         
@@ -321,9 +321,10 @@ class CuemiacTreeView (gtk.TreeView):
         Activate to the first item and scroll to it if C{scroll} is C{True}
         """
         path = self.__find_top_path()
-        if scroll:
-            self.__select_path(path)
-        self.activate_row( self.get_model().get_iter(path) )
+        if path != None:
+            if scroll:
+                self.__select_path(path)
+            self.activate_row( self.get_model().get_iter(path) )
 
     def activate_row(self, iter):
         """
